# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: eolymp/ranker/ranker.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from eolymp.annotations import http_pb2 as eolymp_dot_annotations_dot_http__pb2
from eolymp.annotations import ratelimit_pb2 as eolymp_dot_annotations_dot_ratelimit__pb2
from eolymp.annotations import scope_pb2 as eolymp_dot_annotations_dot_scope__pb2
from eolymp.annotations import service_pb2 as eolymp_dot_annotations_dot_service__pb2
from eolymp.wellknown import expression_pb2 as eolymp_dot_wellknown_dot_expression__pb2
from eolymp.ranker import activity_pb2 as eolymp_dot_ranker_dot_activity__pb2
from eolymp.ranker import scoreboard_pb2 as eolymp_dot_ranker_dot_scoreboard__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='eolymp/ranker/ranker.proto',
  package='eolymp.ranker',
  syntax='proto3',
  serialized_options=b'Z3github.com/eolymp/contracts/go/eolymp/ranker;ranker',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1a\x65olymp/ranker/ranker.proto\x12\reolymp.ranker\x1a\x1d\x65olymp/annotations/http.proto\x1a\"eolymp/annotations/ratelimit.proto\x1a\x1e\x65olymp/annotations/scope.proto\x1a eolymp/annotations/service.proto\x1a!eolymp/wellknown/expression.proto\x1a\x1c\x65olymp/ranker/activity.proto\x1a\x1e\x65olymp/ranker/scoreboard.proto\"F\n\x15\x43reateScoreboardInput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"/\n\x16\x43reateScoreboardOutput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x15UpdateScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12-\n\nscoreboard\x18\x02 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\x18\n\x16UpdateScoreboardOutput\"/\n\x16RebuildScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\".\n\x17RebuildScoreboardOutput\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\".\n\x15\x44\x65leteScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"\x18\n\x16\x44\x65leteScoreboardOutput\"H\n\x17\x44\x65scribeScoreboardInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x16\n\x0escoreboard_key\x18\x02 \x01(\t\"I\n\x18\x44\x65scribeScoreboardOutput\x12-\n\nscoreboard\x18\x01 \x01(\x0b\x32\x19.eolymp.ranker.Scoreboard\"\xa7\x01\n\x14ListScoreboardsInput\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12;\n\x07\x66ilters\x18( \x01(\x0b\x32*.eolymp.ranker.ListScoreboardsInput.Filter\x1a\x34\n\x06\x46ilter\x12*\n\x02id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"P\n\x15ListScoreboardsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12(\n\x05items\x18\x02 \x03(\x0b\x32\x19.eolymp.ranker.Scoreboard\"F\n\x1a\x44\x65scribeScoreboardRowInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x11\n\tmember_id\x18\x02 \x01(\t\"I\n\x1b\x44\x65scribeScoreboardRowOutput\x12*\n\x03row\x18\x01 \x01(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\"\xcb\x01\n\x17ListScoreboardRowsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\x12>\n\x07\x66ilters\x18( \x01(\x0b\x32-.eolymp.ranker.ListScoreboardRowsInput.Filter\x1a;\n\x06\x46ilter\x12\x31\n\tmember_id\x18\x01 \x03(\x0b\x32\x1e.eolymp.wellknown.ExpressionID\"W\n\x18ListScoreboardRowsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12,\n\x05items\x18\x02 \x03(\x0b\x32\x1d.eolymp.ranker.Scoreboard.Row\"c\n\x18\x41\x64\x64ScoreboardColumnInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\".\n\x19\x41\x64\x64ScoreboardColumnOutput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"0\n\x1b\x44\x65leteScoreboardColumnInput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"\x1e\n\x1c\x44\x65leteScoreboardColumnOutput\"2\n\x1d\x44\x65scribeScoreboardColumnInput\x12\x11\n\tcolumn_id\x18\x01 \x01(\t\"R\n\x1e\x44\x65scribeScoreboardColumnOutput\x12\x30\n\x06\x63olumn\x18\x01 \x01(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"3\n\x1aListScoreboardColumnsInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\"]\n\x1bListScoreboardColumnsOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12/\n\x05items\x18\x02 \x03(\x0b\x32 .eolymp.ranker.Scoreboard.Column\"J\n\x13ListActivitiesInput\x12\x15\n\rscoreboard_id\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\n \x01(\x05\x12\x0c\n\x04size\x18\x0b \x01(\x05\"M\n\x14ListActivitiesOutput\x12\r\n\x05total\x18\x01 \x01(\x05\x12&\n\x05items\x18\x02 \x03(\x0b\x32\x17.eolymp.ranker.Activity2\xda\x14\n\x06Ranker\x12\xad\x01\n\x10\x43reateScoreboard\x12$.eolymp.ranker.CreateScoreboardInput\x1a%.eolymp.ranker.CreateScoreboardOutput\"L\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x18\"\x13/ranker/scoreboardsb\x01*\x12\xba\x01\n\x10UpdateScoreboard\x12$.eolymp.ranker.UpdateScoreboardInput\x1a%.eolymp.ranker.UpdateScoreboardOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02%\x1a#/ranker/scoreboards/{scoreboard_id}\x12\xc5\x01\n\x11RebuildScoreboard\x12%.eolymp.ranker.RebuildScoreboardInput\x1a&.eolymp.ranker.RebuildScoreboardOutput\"a\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/ranker/scoreboards/{scoreboard_id}/rebuild\x12\xba\x01\n\x10\x44\x65leteScoreboard\x12$.eolymp.ranker.DeleteScoreboardInput\x1a%.eolymp.ranker.DeleteScoreboardOutput\"Y\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x00@\xf8\xe2\n\n\x82\xd3\xe4\x93\x02%*#/ranker/scoreboards/{scoreboard_id}\x12\x86\x02\n\x12\x44\x65scribeScoreboard\x12&.eolymp.ranker.DescribeScoreboardInput\x1a\'.eolymp.ranker.DescribeScoreboardOutput\"\x9e\x01\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02k\x12#/ranker/scoreboards/{scoreboard_id}Z8\x12*/ranker/scoreboard-lookup/{scoreboard_key}b\nscoreboardb\nscoreboard\x12\xa9\x01\n\x0fListScoreboards\x12#.eolymp.ranker.ListScoreboardsInput\x1a$.eolymp.ranker.ListScoreboardsOutput\"K\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x18\x12\x13/ranker/scoreboardsb\x01*\x12\xdc\x01\n\x15\x44\x65scribeScoreboardRow\x12).eolymp.ranker.DescribeScoreboardRowInput\x1a*.eolymp.ranker.DescribeScoreboardRowOutput\"l\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x39\x12\x34/ranker/scoreboards/{scoreboard_id}/rows/{member_id}b\x01*\x12\xc7\x01\n\x12ListScoreboardRows\x12&.eolymp.ranker.ListScoreboardRowsInput\x1a\'.eolymp.ranker.ListScoreboardRowsOutput\"`\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02-\x12(/ranker/scoreboards/{scoreboard_id}/rowsb\x01*\x12\xcb\x01\n\x13\x41\x64\x64ScoreboardColumn\x12\'.eolymp.ranker.AddScoreboardColumnInput\x1a(.eolymp.ranker.AddScoreboardColumnOutput\"a\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02-\"+/ranker/scoreboards/{scoreboard_id}/columns\x12\xc4\x01\n\x16\x44\x65leteScoreboardColumn\x12*.eolymp.ranker.DeleteScoreboardColumnInput\x1a+.eolymp.ranker.DeleteScoreboardColumnOutput\"Q\x82\xe3\n\x1b\x8a\xe3\n\x17ranker:scoreboard:write\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\x80?\xf8\xe2\n\x05\x82\xd3\xe4\x93\x02\x1d*\x1b/ranker/columns/{column_id}\x12\xcc\x01\n\x18\x44\x65scribeScoreboardColumn\x12,.eolymp.ranker.DescribeScoreboardColumnInput\x1a-.eolymp.ranker.DescribeScoreboardColumnOutput\"S\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02 \x12\x1b/ranker/columns/{column_id}b\x01*\x12\xd3\x01\n\x15ListScoreboardColumns\x12).eolymp.ranker.ListScoreboardColumnsInput\x1a*.eolymp.ranker.ListScoreboardColumnsOutput\"c\x82\xe3\n\x1a\x8a\xe3\n\x16ranker:scoreboard:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00 A\xf8\xe2\nd\x82\xd3\xe4\x93\x02\x30\x12+/ranker/scoreboards/{scoreboard_id}/columnsb\x01*\x12\xbd\x01\n\x0eListActivities\x12\".eolymp.ranker.ListActivitiesInput\x1a#.eolymp.ranker.ListActivitiesOutput\"b\x82\xe3\n\x16\x8a\xe3\n\x12judge:contest:read\xea\xe2\n\x0b\xf5\xe2\n\x00\x00\xa0@\xf8\xe2\n\x14\x82\xd3\xe4\x93\x02\x33\x12./ranker/scoreboards/{scoreboard_id}/activitiesb\x01*\x1a\x06\xb2\xe3\n\x02\x08\x01\x42\x35Z3github.com/eolymp/contracts/go/eolymp/ranker;rankerb\x06proto3'
  ,
  dependencies=[eolymp_dot_annotations_dot_http__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_ratelimit__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_scope__pb2.DESCRIPTOR,eolymp_dot_annotations_dot_service__pb2.DESCRIPTOR,eolymp_dot_wellknown_dot_expression__pb2.DESCRIPTOR,eolymp_dot_ranker_dot_activity__pb2.DESCRIPTOR,eolymp_dot_ranker_dot_scoreboard__pb2.DESCRIPTOR,])




_CREATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='CreateScoreboardInput',
  full_name='eolymp.ranker.CreateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.CreateScoreboardInput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=275,
  serialized_end=345,
)


_CREATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='CreateScoreboardOutput',
  full_name='eolymp.ranker.CreateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.CreateScoreboardOutput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=347,
  serialized_end=394,
)


_UPDATESCOREBOARDINPUT = _descriptor.Descriptor(
  name='UpdateScoreboardInput',
  full_name='eolymp.ranker.UpdateScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.UpdateScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.UpdateScoreboardInput.scoreboard', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=396,
  serialized_end=489,
)


_UPDATESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='UpdateScoreboardOutput',
  full_name='eolymp.ranker.UpdateScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=491,
  serialized_end=515,
)


_REBUILDSCOREBOARDINPUT = _descriptor.Descriptor(
  name='RebuildScoreboardInput',
  full_name='eolymp.ranker.RebuildScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.RebuildScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=517,
  serialized_end=564,
)


_REBUILDSCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='RebuildScoreboardOutput',
  full_name='eolymp.ranker.RebuildScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='activity_id', full_name='eolymp.ranker.RebuildScoreboardOutput.activity_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=612,
)


_DELETESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DeleteScoreboardInput',
  full_name='eolymp.ranker.DeleteScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DeleteScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=614,
  serialized_end=660,
)


_DELETESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DeleteScoreboardOutput',
  full_name='eolymp.ranker.DeleteScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=662,
  serialized_end=686,
)


_DESCRIBESCOREBOARDINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardInput',
  full_name='eolymp.ranker.DescribeScoreboardInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DescribeScoreboardInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='scoreboard_key', full_name='eolymp.ranker.DescribeScoreboardInput.scoreboard_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=688,
  serialized_end=760,
)


_DESCRIBESCOREBOARDOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardOutput',
  full_name='eolymp.ranker.DescribeScoreboardOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard', full_name='eolymp.ranker.DescribeScoreboardOutput.scoreboard', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=762,
  serialized_end=835,
)


_LISTSCOREBOARDSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.ranker.ListScoreboardsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='eolymp.ranker.ListScoreboardsInput.Filter.id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=953,
  serialized_end=1005,
)

_LISTSCOREBOARDSINPUT = _descriptor.Descriptor(
  name='ListScoreboardsInput',
  full_name='eolymp.ranker.ListScoreboardsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.ranker.ListScoreboardsInput.offset', index=0,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.ranker.ListScoreboardsInput.size', index=1,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.ranker.ListScoreboardsInput.filters', index=2,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSCOREBOARDSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=838,
  serialized_end=1005,
)


_LISTSCOREBOARDSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardsOutput',
  full_name='eolymp.ranker.ListScoreboardsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1007,
  serialized_end=1087,
)


_DESCRIBESCOREBOARDROWINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardRowInput',
  full_name='eolymp.ranker.DescribeScoreboardRowInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.DescribeScoreboardRowInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.ranker.DescribeScoreboardRowInput.member_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1089,
  serialized_end=1159,
)


_DESCRIBESCOREBOARDROWOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardRowOutput',
  full_name='eolymp.ranker.DescribeScoreboardRowOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='row', full_name='eolymp.ranker.DescribeScoreboardRowOutput.row', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1234,
)


_LISTSCOREBOARDROWSINPUT_FILTER = _descriptor.Descriptor(
  name='Filter',
  full_name='eolymp.ranker.ListScoreboardRowsInput.Filter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='member_id', full_name='eolymp.ranker.ListScoreboardRowsInput.Filter.member_id', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1381,
  serialized_end=1440,
)

_LISTSCOREBOARDROWSINPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsInput',
  full_name='eolymp.ranker.ListScoreboardRowsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.ListScoreboardRowsInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.ranker.ListScoreboardRowsInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.ranker.ListScoreboardRowsInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filters', full_name='eolymp.ranker.ListScoreboardRowsInput.filters', index=3,
      number=40, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_LISTSCOREBOARDROWSINPUT_FILTER, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1237,
  serialized_end=1440,
)


_LISTSCOREBOARDROWSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardRowsOutput',
  full_name='eolymp.ranker.ListScoreboardRowsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardRowsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardRowsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1442,
  serialized_end=1529,
)


_ADDSCOREBOARDCOLUMNINPUT = _descriptor.Descriptor(
  name='AddScoreboardColumnInput',
  full_name='eolymp.ranker.AddScoreboardColumnInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.AddScoreboardColumnInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='column', full_name='eolymp.ranker.AddScoreboardColumnInput.column', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1531,
  serialized_end=1630,
)


_ADDSCOREBOARDCOLUMNOUTPUT = _descriptor.Descriptor(
  name='AddScoreboardColumnOutput',
  full_name='eolymp.ranker.AddScoreboardColumnOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_id', full_name='eolymp.ranker.AddScoreboardColumnOutput.column_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1632,
  serialized_end=1678,
)


_DELETESCOREBOARDCOLUMNINPUT = _descriptor.Descriptor(
  name='DeleteScoreboardColumnInput',
  full_name='eolymp.ranker.DeleteScoreboardColumnInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_id', full_name='eolymp.ranker.DeleteScoreboardColumnInput.column_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1680,
  serialized_end=1728,
)


_DELETESCOREBOARDCOLUMNOUTPUT = _descriptor.Descriptor(
  name='DeleteScoreboardColumnOutput',
  full_name='eolymp.ranker.DeleteScoreboardColumnOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1730,
  serialized_end=1760,
)


_DESCRIBESCOREBOARDCOLUMNINPUT = _descriptor.Descriptor(
  name='DescribeScoreboardColumnInput',
  full_name='eolymp.ranker.DescribeScoreboardColumnInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column_id', full_name='eolymp.ranker.DescribeScoreboardColumnInput.column_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1762,
  serialized_end=1812,
)


_DESCRIBESCOREBOARDCOLUMNOUTPUT = _descriptor.Descriptor(
  name='DescribeScoreboardColumnOutput',
  full_name='eolymp.ranker.DescribeScoreboardColumnOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='eolymp.ranker.DescribeScoreboardColumnOutput.column', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1814,
  serialized_end=1896,
)


_LISTSCOREBOARDCOLUMNSINPUT = _descriptor.Descriptor(
  name='ListScoreboardColumnsInput',
  full_name='eolymp.ranker.ListScoreboardColumnsInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.ListScoreboardColumnsInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1898,
  serialized_end=1949,
)


_LISTSCOREBOARDCOLUMNSOUTPUT = _descriptor.Descriptor(
  name='ListScoreboardColumnsOutput',
  full_name='eolymp.ranker.ListScoreboardColumnsOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListScoreboardColumnsOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListScoreboardColumnsOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1951,
  serialized_end=2044,
)


_LISTACTIVITIESINPUT = _descriptor.Descriptor(
  name='ListActivitiesInput',
  full_name='eolymp.ranker.ListActivitiesInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='scoreboard_id', full_name='eolymp.ranker.ListActivitiesInput.scoreboard_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='offset', full_name='eolymp.ranker.ListActivitiesInput.offset', index=1,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='size', full_name='eolymp.ranker.ListActivitiesInput.size', index=2,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2046,
  serialized_end=2120,
)


_LISTACTIVITIESOUTPUT = _descriptor.Descriptor(
  name='ListActivitiesOutput',
  full_name='eolymp.ranker.ListActivitiesOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='total', full_name='eolymp.ranker.ListActivitiesOutput.total', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='items', full_name='eolymp.ranker.ListActivitiesOutput.items', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2122,
  serialized_end=2199,
)

_CREATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_UPDATESCOREBOARDINPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBESCOREBOARDOUTPUT.fields_by_name['scoreboard'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_LISTSCOREBOARDSINPUT_FILTER.fields_by_name['id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDSINPUT_FILTER.containing_type = _LISTSCOREBOARDSINPUT
_LISTSCOREBOARDSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDSINPUT_FILTER
_LISTSCOREBOARDSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD
_DESCRIBESCOREBOARDROWOUTPUT.fields_by_name['row'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_ROW
_LISTSCOREBOARDROWSINPUT_FILTER.fields_by_name['member_id'].message_type = eolymp_dot_wellknown_dot_expression__pb2._EXPRESSIONID
_LISTSCOREBOARDROWSINPUT_FILTER.containing_type = _LISTSCOREBOARDROWSINPUT
_LISTSCOREBOARDROWSINPUT.fields_by_name['filters'].message_type = _LISTSCOREBOARDROWSINPUT_FILTER
_LISTSCOREBOARDROWSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_ROW
_ADDSCOREBOARDCOLUMNINPUT.fields_by_name['column'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_COLUMN
_DESCRIBESCOREBOARDCOLUMNOUTPUT.fields_by_name['column'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_COLUMN
_LISTSCOREBOARDCOLUMNSOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_scoreboard__pb2._SCOREBOARD_COLUMN
_LISTACTIVITIESOUTPUT.fields_by_name['items'].message_type = eolymp_dot_ranker_dot_activity__pb2._ACTIVITY
DESCRIPTOR.message_types_by_name['CreateScoreboardInput'] = _CREATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['CreateScoreboardOutput'] = _CREATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardInput'] = _UPDATESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['UpdateScoreboardOutput'] = _UPDATESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardInput'] = _REBUILDSCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['RebuildScoreboardOutput'] = _REBUILDSCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardInput'] = _DELETESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardOutput'] = _DELETESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardInput'] = _DESCRIBESCOREBOARDINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardOutput'] = _DESCRIBESCOREBOARDOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsInput'] = _LISTSCOREBOARDSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardsOutput'] = _LISTSCOREBOARDSOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardRowInput'] = _DESCRIBESCOREBOARDROWINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardRowOutput'] = _DESCRIBESCOREBOARDROWOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsInput'] = _LISTSCOREBOARDROWSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardRowsOutput'] = _LISTSCOREBOARDROWSOUTPUT
DESCRIPTOR.message_types_by_name['AddScoreboardColumnInput'] = _ADDSCOREBOARDCOLUMNINPUT
DESCRIPTOR.message_types_by_name['AddScoreboardColumnOutput'] = _ADDSCOREBOARDCOLUMNOUTPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardColumnInput'] = _DELETESCOREBOARDCOLUMNINPUT
DESCRIPTOR.message_types_by_name['DeleteScoreboardColumnOutput'] = _DELETESCOREBOARDCOLUMNOUTPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardColumnInput'] = _DESCRIBESCOREBOARDCOLUMNINPUT
DESCRIPTOR.message_types_by_name['DescribeScoreboardColumnOutput'] = _DESCRIBESCOREBOARDCOLUMNOUTPUT
DESCRIPTOR.message_types_by_name['ListScoreboardColumnsInput'] = _LISTSCOREBOARDCOLUMNSINPUT
DESCRIPTOR.message_types_by_name['ListScoreboardColumnsOutput'] = _LISTSCOREBOARDCOLUMNSOUTPUT
DESCRIPTOR.message_types_by_name['ListActivitiesInput'] = _LISTACTIVITIESINPUT
DESCRIPTOR.message_types_by_name['ListActivitiesOutput'] = _LISTACTIVITIESOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateScoreboardInput = _reflection.GeneratedProtocolMessageType('CreateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.CreateScoreboardInput)
  })
_sym_db.RegisterMessage(CreateScoreboardInput)

CreateScoreboardOutput = _reflection.GeneratedProtocolMessageType('CreateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _CREATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.CreateScoreboardOutput)
  })
_sym_db.RegisterMessage(CreateScoreboardOutput)

UpdateScoreboardInput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UpdateScoreboardInput)
  })
_sym_db.RegisterMessage(UpdateScoreboardInput)

UpdateScoreboardOutput = _reflection.GeneratedProtocolMessageType('UpdateScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.UpdateScoreboardOutput)
  })
_sym_db.RegisterMessage(UpdateScoreboardOutput)

RebuildScoreboardInput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardInput)
  })
_sym_db.RegisterMessage(RebuildScoreboardInput)

RebuildScoreboardOutput = _reflection.GeneratedProtocolMessageType('RebuildScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _REBUILDSCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.RebuildScoreboardOutput)
  })
_sym_db.RegisterMessage(RebuildScoreboardOutput)

DeleteScoreboardInput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardInput)
  })
_sym_db.RegisterMessage(DeleteScoreboardInput)

DeleteScoreboardOutput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardOutput)
  })
_sym_db.RegisterMessage(DeleteScoreboardOutput)

DescribeScoreboardInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardInput)

DescribeScoreboardOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardOutput)

ListScoreboardsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCOREBOARDSINPUT_FILTER,
    '__module__' : 'eolymp.ranker.ranker_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSCOREBOARDSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsInput)
  })
_sym_db.RegisterMessage(ListScoreboardsInput)
_sym_db.RegisterMessage(ListScoreboardsInput.Filter)

ListScoreboardsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardsOutput)

DescribeScoreboardRowInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardRowInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDROWINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardRowInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardRowInput)

DescribeScoreboardRowOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardRowOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDROWOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardRowOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardRowOutput)

ListScoreboardRowsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsInput', (_message.Message,), {

  'Filter' : _reflection.GeneratedProtocolMessageType('Filter', (_message.Message,), {
    'DESCRIPTOR' : _LISTSCOREBOARDROWSINPUT_FILTER,
    '__module__' : 'eolymp.ranker.ranker_pb2'
    # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsInput.Filter)
    })
  ,
  'DESCRIPTOR' : _LISTSCOREBOARDROWSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsInput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsInput)
_sym_db.RegisterMessage(ListScoreboardRowsInput.Filter)

ListScoreboardRowsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardRowsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDROWSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardRowsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardRowsOutput)

AddScoreboardColumnInput = _reflection.GeneratedProtocolMessageType('AddScoreboardColumnInput', (_message.Message,), {
  'DESCRIPTOR' : _ADDSCOREBOARDCOLUMNINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.AddScoreboardColumnInput)
  })
_sym_db.RegisterMessage(AddScoreboardColumnInput)

AddScoreboardColumnOutput = _reflection.GeneratedProtocolMessageType('AddScoreboardColumnOutput', (_message.Message,), {
  'DESCRIPTOR' : _ADDSCOREBOARDCOLUMNOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.AddScoreboardColumnOutput)
  })
_sym_db.RegisterMessage(AddScoreboardColumnOutput)

DeleteScoreboardColumnInput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardColumnInput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDCOLUMNINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardColumnInput)
  })
_sym_db.RegisterMessage(DeleteScoreboardColumnInput)

DeleteScoreboardColumnOutput = _reflection.GeneratedProtocolMessageType('DeleteScoreboardColumnOutput', (_message.Message,), {
  'DESCRIPTOR' : _DELETESCOREBOARDCOLUMNOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DeleteScoreboardColumnOutput)
  })
_sym_db.RegisterMessage(DeleteScoreboardColumnOutput)

DescribeScoreboardColumnInput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardColumnInput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDCOLUMNINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardColumnInput)
  })
_sym_db.RegisterMessage(DescribeScoreboardColumnInput)

DescribeScoreboardColumnOutput = _reflection.GeneratedProtocolMessageType('DescribeScoreboardColumnOutput', (_message.Message,), {
  'DESCRIPTOR' : _DESCRIBESCOREBOARDCOLUMNOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.DescribeScoreboardColumnOutput)
  })
_sym_db.RegisterMessage(DescribeScoreboardColumnOutput)

ListScoreboardColumnsInput = _reflection.GeneratedProtocolMessageType('ListScoreboardColumnsInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDCOLUMNSINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardColumnsInput)
  })
_sym_db.RegisterMessage(ListScoreboardColumnsInput)

ListScoreboardColumnsOutput = _reflection.GeneratedProtocolMessageType('ListScoreboardColumnsOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTSCOREBOARDCOLUMNSOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListScoreboardColumnsOutput)
  })
_sym_db.RegisterMessage(ListScoreboardColumnsOutput)

ListActivitiesInput = _reflection.GeneratedProtocolMessageType('ListActivitiesInput', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVITIESINPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListActivitiesInput)
  })
_sym_db.RegisterMessage(ListActivitiesInput)

ListActivitiesOutput = _reflection.GeneratedProtocolMessageType('ListActivitiesOutput', (_message.Message,), {
  'DESCRIPTOR' : _LISTACTIVITIESOUTPUT,
  '__module__' : 'eolymp.ranker.ranker_pb2'
  # @@protoc_insertion_point(class_scope:eolymp.ranker.ListActivitiesOutput)
  })
_sym_db.RegisterMessage(ListActivitiesOutput)


DESCRIPTOR._options = None

_RANKER = _descriptor.ServiceDescriptor(
  name='Ranker',
  full_name='eolymp.ranker.Ranker',
  file=DESCRIPTOR,
  index=0,
  serialized_options=b'\262\343\n\002\010\001',
  create_key=_descriptor._internal_create_key,
  serialized_start=2202,
  serialized_end=4852,
  methods=[
  _descriptor.MethodDescriptor(
    name='CreateScoreboard',
    full_name='eolymp.ranker.Ranker.CreateScoreboard',
    index=0,
    containing_service=None,
    input_type=_CREATESCOREBOARDINPUT,
    output_type=_CREATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\030\"\023/ranker/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateScoreboard',
    full_name='eolymp.ranker.Ranker.UpdateScoreboard',
    index=1,
    containing_service=None,
    input_type=_UPDATESCOREBOARDINPUT,
    output_type=_UPDATESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002%\032#/ranker/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RebuildScoreboard',
    full_name='eolymp.ranker.Ranker.RebuildScoreboard',
    index=2,
    containing_service=None,
    input_type=_REBUILDSCOREBOARDINPUT,
    output_type=_REBUILDSCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/ranker/scoreboards/{scoreboard_id}/rebuild',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteScoreboard',
    full_name='eolymp.ranker.Ranker.DeleteScoreboard',
    index=3,
    containing_service=None,
    input_type=_DELETESCOREBOARDINPUT,
    output_type=_DELETESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\000@\370\342\n\n\202\323\344\223\002%*#/ranker/scoreboards/{scoreboard_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboard',
    full_name='eolymp.ranker.Ranker.DescribeScoreboard',
    index=4,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDINPUT,
    output_type=_DESCRIBESCOREBOARDOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002k\022#/ranker/scoreboards/{scoreboard_id}Z8\022*/ranker/scoreboard-lookup/{scoreboard_key}b\nscoreboardb\nscoreboard',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboards',
    full_name='eolymp.ranker.Ranker.ListScoreboards',
    index=5,
    containing_service=None,
    input_type=_LISTSCOREBOARDSINPUT,
    output_type=_LISTSCOREBOARDSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\002\030\022\023/ranker/scoreboardsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboardRow',
    full_name='eolymp.ranker.Ranker.DescribeScoreboardRow',
    index=6,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDROWINPUT,
    output_type=_DESCRIBESCOREBOARDROWOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\0029\0224/ranker/scoreboards/{scoreboard_id}/rows/{member_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboardRows',
    full_name='eolymp.ranker.Ranker.ListScoreboardRows',
    index=7,
    containing_service=None,
    input_type=_LISTSCOREBOARDROWSINPUT,
    output_type=_LISTSCOREBOARDROWSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002-\022(/ranker/scoreboards/{scoreboard_id}/rowsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddScoreboardColumn',
    full_name='eolymp.ranker.Ranker.AddScoreboardColumn',
    index=8,
    containing_service=None,
    input_type=_ADDSCOREBOARDCOLUMNINPUT,
    output_type=_ADDSCOREBOARDCOLUMNOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002-\"+/ranker/scoreboards/{scoreboard_id}/columns',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteScoreboardColumn',
    full_name='eolymp.ranker.Ranker.DeleteScoreboardColumn',
    index=9,
    containing_service=None,
    input_type=_DELETESCOREBOARDCOLUMNINPUT,
    output_type=_DELETESCOREBOARDCOLUMNOUTPUT,
    serialized_options=b'\202\343\n\033\212\343\n\027ranker:scoreboard:write\352\342\n\013\365\342\n\000\000\200?\370\342\n\005\202\323\344\223\002\035*\033/ranker/columns/{column_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DescribeScoreboardColumn',
    full_name='eolymp.ranker.Ranker.DescribeScoreboardColumn',
    index=10,
    containing_service=None,
    input_type=_DESCRIBESCOREBOARDCOLUMNINPUT,
    output_type=_DESCRIBESCOREBOARDCOLUMNOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\002 \022\033/ranker/columns/{column_id}b\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListScoreboardColumns',
    full_name='eolymp.ranker.Ranker.ListScoreboardColumns',
    index=11,
    containing_service=None,
    input_type=_LISTSCOREBOARDCOLUMNSINPUT,
    output_type=_LISTSCOREBOARDCOLUMNSOUTPUT,
    serialized_options=b'\202\343\n\032\212\343\n\026ranker:scoreboard:read\352\342\n\013\365\342\n\000\000 A\370\342\nd\202\323\344\223\0020\022+/ranker/scoreboards/{scoreboard_id}/columnsb\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListActivities',
    full_name='eolymp.ranker.Ranker.ListActivities',
    index=12,
    containing_service=None,
    input_type=_LISTACTIVITIESINPUT,
    output_type=_LISTACTIVITIESOUTPUT,
    serialized_options=b'\202\343\n\026\212\343\n\022judge:contest:read\352\342\n\013\365\342\n\000\000\240@\370\342\n\024\202\323\344\223\0023\022./ranker/scoreboards/{scoreboard_id}/activitiesb\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_RANKER)

DESCRIPTOR.services_by_name['Ranker'] = _RANKER

# @@protoc_insertion_point(module_scope)
